# -*- coding: utf-8 -*-

from app.utils.constant import SAY_SOMETHING, DASHED, UTF, IA

from app.base import Base_CGPT


def prompt() -> None:
    cgpt = Base_CGPT(
        exit_key="q",
        modify_api_key="m",
        input_text=SAY_SOMETHING,
        decoration=DASHED,
        encode=UTF,
        icon_ans=IA,
        socket_resp=False,
        socket_instance=None,
    )

    cgpt.infinite_loop()



# -*- coding: utf-8 -*-

import click, os, getpass, dotenv
from termcolor import colored
from app.utils.constant import (
    GET_API_KEY,
    API_KEY_ADDED,
    API_KEY_NOT_ADDED,
    STR_OPENAI_API_KEY,
    color,
)


def file_prompt(output_path=None) -> None:
    api_key = getpass.getpass(GET_API_KEY)

    if output_path is None:
        output_path = ""

    if api_key:
        fichier = open(output_path + ".env", "w")
        fichier.close()
        dotenv.set_key(output_path + ".env", STR_OPENAI_API_KEY, api_key)

        click.echo(colored(API_KEY_ADDED, color))

    elif api_key == "" or not api_key:
        click.echo(colored(API_KEY_NOT_ADDED, color))



# -*- coding: utf-8 -*-

import ipaddress
import socket, click
from termcolor import colored
from app.utils.constant import (
    UTF,
    IA,
    SAY_SOMETHING,
    ENTER_SERVER_IP,
    CONNECTION_ERROR,
    CONNECTION_IMPOSSIBLE,
    DASHED,
    PORT,
    ADDRESS_NOT_VALID,
    error_color,
)

from app.utils.verify_env import _check_env_file
from app.base import Base_CGPT


def main():
    adresse_ip = click.prompt(colored(ENTER_SERVER_IP, error_color))

    try:
        ipaddress.IPv4Address(adresse_ip)
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        try:
            s.connect((adresse_ip, int(PORT)))
            Base_CGPT._void_func = _check_env_file

            cgpt = Base_CGPT(
                exit_key="q",
                modify_api_key="m",
                input_text=SAY_SOMETHING,
                decoration=DASHED,
                encode=UTF,
                icon_ans=IA,
                socket_resp=True,
                socket_instance=s,
            )

            cgpt.infinite_loop()

        except OSError as e:
            if e.errno == 113:
                click.echo(colored(CONNECTION_IMPOSSIBLE, error_color))
            else:
                click.echo(colored(f"{CONNECTION_ERROR} {e}", error_color))

        finally:
            s.close()

    except ipaddress.AddressValueError:
        click.echo(ADDRESS_NOT_VALID)


if __name__ == "__main__":
    main()



from typing import List, Dict
import click, socket
from app.create_env import file_prompt
from app.plugin import davinci
from app.utils.constant import (
    init_conversation,
    ASSISTANT,
    MAX_WIDTH,
    color,
    top_left,
    bottom_left,
    IA,
    stick,
    BLANK,
    assistant_color,
)
from termcolor import colored


class Base_CGPT:

    """
    Baseclass to create a conversational infinite-loop with CGPT module
    """

    def __init__(
        self,
        exit_key: str,
        modify_api_key: str,
        input_text: str,
        decoration: str,
        encode: str,
        socket_resp: bool,
        icon_ans: str,
        socket_instance: socket = None,
    ) -> None:
        self.exit_key = exit_key
        self.modify_api_key = modify_api_key
        self.input_text = input_text
        self.decoration = decoration
        self.icon_ans = icon_ans
        self.encode = encode
        self.socket_resp = socket_resp
        self.socket_instance = socket_instance

    def _anonym_func(self, *args):
        return args[0]

    def _void_func(self) -> None:
        pass

    def _I_O_func(
        self,
        socket_resp: bool,
        previous_conv: List[Dict],
        client_input: str = None,
        socket=None,
    ) -> str:
        if socket_resp:
            if client_input is not None:
                socket.send(client_input.encode(self.encode.lower()))

            elif client_input == self.exit_key:
                return

            elif client_input == self.modify_api_key:
                file_prompt()
                return

            data = socket.recv(1024)
            res = str(data.decode(self.encode.lower()))
        else:
            res = davinci(client_input, previous_conv)

        return res

    def infinite_loop(self) -> None:
        while True:
            self._void_func()
            click.echo(BLANK)
            client = input(colored(self.input_text, assistant_color))
            click.echo(BLANK)
            if client == self.exit_key:
                break

            elif client == self.modify_api_key:
                file_prompt()
                break

            resp = self._I_O_func(
                self.socket_resp,
                previous_conv=init_conversation,
                client_input=client,
                socket=self.socket_instance,
            )
            init_conversation.append({"role": ASSISTANT, "content": resp})
            if resp is None:
                break

            result = resp
            len_res = len(result)
            emoji_str = IA.encode("utf-8").decode("utf-8") if IA != "IA" else "IA"

            if len(result) > MAX_WIDTH - 4:
                len_res = MAX_WIDTH - 4
            else:
                len_res = len(result)

            wrapped_result = [result]

            box = (
                colored(top_left, color)
                + colored("─", color) * (len_res + 2)
                + " "
                + emoji_str
                + "\n"
            )
            box += colored(stick, color) + " " * (len_res + 2) + "\n"

            for line in wrapped_result:
                box += (
                    colored(stick, color)
                    + " "
                    + colored(line)
                    + " " * (MAX_WIDTH - len(line) - 3)
                    + "\n"
                )

            box += colored(stick, color) + " " * (len_res + 2) + "\n"
            box += colored(bottom_left, color) + colored("─", color) * (len_res + 2)

            click.echo(box)



# -*- coding: utf-8 -*-

import click, os, subprocess
from termcolor import colored
from app.main import prompt
from app.create_env import file_prompt
from app.utils.constant import (
    SERVER_PATH,
    CLIENT_PATH,
    CGPT_NETWORK,
    YOU_SERVER,
    OPEN_TERMINAL,
    WELCOME,
    error_color,
    color,
    BOLD,
    PYTHONSTR,
)


@click.command()
def cgpt():
    click.echo(colored(WELCOME, color=color, attrs=[BOLD]))

    cgpt_path = os.path.abspath(os.path.dirname(__file__))
    use_in_lan = click.confirm(colored(CGPT_NETWORK, error_color))

    if use_in_lan:
        endpoint = click.confirm(colored(YOU_SERVER, error_color))

        if endpoint:
            click.echo(colored(OPEN_TERMINAL, error_color))
            subprocess.run([PYTHONSTR, cgpt_path + SERVER_PATH])

        else:
            subprocess.run([PYTHONSTR, cgpt_path + CLIENT_PATH])

    else:
        if not os.path.isfile(".env"):
            file_prompt()
        else:
            prompt()



# -*- coding: utf-8 -*-

import os, click
from termcolor import colored
from typing import Union, List, Dict
import openai
from app.create_env import file_prompt
from dotenv import load_dotenv

load_dotenv()
from app.utils.constant import (
    AI_COLON,
    CHOICES,
    STR_OPENAI_API_KEY,
    DAVINCI_MODEL,
    INCORRECT_API_KEY,
    MESSAGE,
    CONTENT,
    OPENAI_REQUEST_TIMEOUT,
    NOT_CONNECTED,
    TOO_MUCH_REQUEST,
    USER,
    error_color,
)

openai.api_key = os.getenv(STR_OPENAI_API_KEY)


def davinci(what: str, previous_conv: List[Dict]) -> Union[str, None]:
    try:
        previous_conv.append({"role": USER, "content": what})
        response = openai.ChatCompletion.create(
            model=DAVINCI_MODEL, messages=previous_conv
        )

        res = response[CHOICES][0][MESSAGE][CONTENT].replace(AI_COLON, "")

    except openai.error.AuthenticationError:
        modify_apikey = input(INCORRECT_API_KEY)

        if modify_apikey == "m":
            file_prompt()
            res = None

        else:
            res = None

    except openai.error.Timeout:
        click.echo(colored(OPENAI_REQUEST_TIMEOUT, error_color))
        res = None

    except openai.error.APIConnectionError:
        click.echo(colored(NOT_CONNECTED, error_color))
        res = None

    except openai.error.RateLimitError:
        click.echo(colored(TOO_MUCH_REQUEST, error_color))
        res = None

    return res



# -*- coding: utf-8 -*-

import socket, click
from _thread import *
import threading
from termcolor import colored

print_lock = threading.Lock()
from app.plugin import davinci
from app.utils.constant import (
    PORT,
    SERVER_LIVE,
    UTF,
    LIVE,
    PING,
    PONG,
    DECONNECTED_HOST,
    init_conversation,
    error_color,
    color,
)


def threaded(c):
    init_conversation_client = init_conversation
    while True:
        try:
            client_data = c.recv(1024).decode()

            if client_data == PING:
                c.send(PONG.encode(encoding=UTF))

            api_response = davinci(client_data, init_conversation_client)
            if api_response is not None:
                c.send(api_response.encode(encoding=UTF))
            else:
                continue

        except BrokenPipeError:
            continue

        except ConnectionResetError:
            click.echo(colored(DECONNECTED_HOST, error_color))


def main(port, ip_address=None):
    if ip_address is None:
        auto_detcted_ip = socket.gethostbyname(socket.gethostname())
        server_socket = socket.create_server(
            (auto_detcted_ip, int(port)), reuse_port=False
        )
        server_socket.listen()
        click.echo(colored(f"{SERVER_LIVE} {auto_detcted_ip} ..{LIVE}", color))

    else:
        server_socket = socket.create_server((ip_address, int(port)), reuse_port=False)
        server_socket.listen()

    while True:
        client, _ = server_socket.accept()
        threading.Thread(target=threaded, args=(client,), daemon=True).start()


if __name__ == "__main__":
    main(PORT, None)



import platform

VERSION = "1.2.2"
SUBTITLE = ">>> Make AI powered search inside your CLI"
os_name = platform.system()

WELCOME = f"""

  /$$$$$$   /$$$$$$  /$$$$$$$  /$$$$$$$$    
 /$$__  $$ /$$__  $$| $$__  $$|__  $$__/ v{VERSION}     
| $$  \__/| $$  \__/| $$  \ $$   | $$         
| $$      | $$ /$$$$| $$$$$$$/   | $$         
| $$      | $$|_  $$| $$____/    | $$         
| $$    $$| $$  \ $$| $$         | $$         
|  $$$$$$/|  $$$$$$/| $$         | $$         
 \______/  \______/ |__/         |__/ {SUBTITLE}

"""


if os_name == "Linux" or os_name == "Darwin":
    IA = "🤖"
    HAPPY = "😃"
    RELEIVED = "😌"
    SAD = "😥"
    NO_ENTRY = "🚫"
    LIVE = "✨"
else:
    IA = "IA"
    HAPPY = ""
    RELEIVED = ""
    SAD = ""
    NO_ENTRY = ""
    LIVE = ""

init_conversation = [{"role": "system", "content": "You are a helpful assistant."}]
color = "green"
error_color = "yellow"
assistant_color = "yellow"
top_left = "╭"
top_right = "╮"
bottom_left = "╰"
bottom_right = "╯"
stick = "│"
BLANK = "\n"
TEMPERATURE = 0.9
MAX_TOKENS = 200
TOP_P = 1.0
FREQUENCY_P = 0.0
PRESENCE_P = 0.6
PORT = 2048
PORT = "2048"
UTF = "UTF-8"
BEGIN = "begin"
HUMAN = " Human:"
USER = "user"
ASSISTANT = "assistant"
AI_COLON = "AI:"
AI_COLON_SPACE = " AI:"
CHOICES = "choices"
TEXT = "text"
MAX_WIDTH = 100
MESSAGE = "message"
CONTENT = "content"
STR_OPENAI_API_KEY = "OPENAI_API_KEY"
SERVER_PATH = "/app/server/main.py"
CLIENT_PATH = "/app/client/main.py"
CGPT_NETWORK = "Do you want to use cgpt on networks? "
YOU_SERVER = f"Are you the server {HAPPY}?"
OPEN_TERMINAL = f"Please open another terminal..{RELEIVED}"
SERVER_LIVE = "Server live on "
GET_API_KEY = "Add your API key (invisible input) > "
API_KEY_ADDED = (
    "Your API key has been successfully added, please restart the cgpt command."
)
API_KEY_NOT_ADDED = "\nYou have not added an API key.\n"
SAY_SOMETHING = "Say something (q: quit, m: modify api_key) > "
ENTER_SERVER_IP = "Enter the server IP address: "
CONNECTION_LOST = f"Connection lost {SAD}"
CONNECTION_IMPOSSIBLE = f"Connection impossible {SAD}"
DASHED = "----------------------------------------------------------"
DAVINCI_MODEL = "gpt-3.5-turbo"
DAVINCI_PROMPT = "The following is a conversation with an AI. The AI is helpful, creative, clever, and very friendly.\n\nHuman:"
INCORRECT_API_KEY = (
    "Your API key is incorrect. Type m to modify the key or q to quit > "
)
OPENAI_REQUEST_TIMEOUT = "AI is asleep"
NOT_CONNECTED = "You are not connected to the internet.."
TOO_MUCH_REQUEST = "Too many requests"
CONNECTION_ERROR = "Connection error: "
ADDRESS_NOT_VALID = f"The IP address is not valid {NO_ENTRY}"
DECONNECTED_HOST = "A host has disconnected."
BOLD = "bold"
PYTHONSTR = "python"
PING = "PING"
PONG = "PONG"



# -*- coding: utf-8 -*-

from setuptools import setup
from app.utils.constant import VERSION

with open("pypi_desc.md", "r", encoding="utf-8") as fh:
    long_desc = fh.read()

with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()

setup(
    name="cgpt",
    version=VERSION,
    author="Aina Yves",
    author_email="randrianaina.yves@gmail.com",
    license="MIT",
    description="Use openai chat-gpt on your cli",
    long_description=long_desc,
    url="https://github.com/ainayves/cgpt>",
    long_description_content_type="text/markdown",
    py_modules=["cgpt", "app"],
    packages=["app", "app.client", "app.server", "app.utils", "app.commands"],
    install_requires=[
        "setuptools",
        "twine",
        "click>=7.1.2",
        "openai",
        "python-dotenv",
        "termcolor"
    ],
    python_requires=">=3.7",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    entry_points={
        "console_scripts": ["cgpt=cgpt:cgpt", "cgpt-version=app.commands.main:version"]
    },
)
